@@ -1,6 +1,6 @@
 class Dict(dict):
-    def __init__(self,**kwargs):
-        super().__init__(kwargs)
+    def __init__(self,*args,**kwargs):
+        super().__init__(,*args,**kwargs)
         self.__dict__=self
     def update(self,args):
         super().update(args)
